@@ -13,8 +13,8 @@ import glob
 import os.path
 import logging
 
-__version__ = '0.1.0'
-__release__ = 20230201
+__version__ = '0.1.2'
+__release__ = 20230203
 __all__ = ['read', 'concat']
 
 
@@ -41,11 +41,11 @@ def _read_one(path: str, raise_error=True, use_simpandas=None):
         else:
             logging.warning("The provided path can't be found:\n" + str(path))
     if path.split('.')[-1].lower() == 'las':
-        return las2frame(path, use_simpandas=use_simpandas)
+        return las2frame(path, use_simpandas=use_simpandas, raise_error=raise_error)
     elif path.split('.')[-1].lower() == 'dlis':
-        return dlis2frame(path, use_simpandas=use_simpandas)
+        return dlis2frame(path, use_simpandas=use_simpandas, raise_error=raise_error)
     elif path.split('.')[-1].lower() == 'lis':
-        return lis2frame(path, use_simpandas=use_simpandas)
+        return lis2frame(path, use_simpandas=use_simpandas, raise_error=raise_error)
     elif not raise_error:
         logging.warning("Not a valid log file: " + str(path))
         return None
@@ -53,7 +53,7 @@ def _read_one(path: str, raise_error=True, use_simpandas=None):
         raise ValueError("`path` should be a '.las' or '.dlis' file")
 
 
-def read(path: str, recursive=True, raise_error=None, squeeze=True, use_simpandas=None):
+def read(path: str, recursive=True, raise_error=False, squeeze=True, use_simpandas=None):
     if use_simpandas is not None and use_simpandas is True and not _params_.simpandas_:
         raise ModuleNotFoundError("SimPandas is not installed, please install it or set parameter `use_simpandas` to False.")
     use_simpandas = _params_.simpandas_ if use_simpandas is None else bool(use_simpandas)
