@@ -10,8 +10,8 @@ import pandas as pd
 import unyts
 
 
-__version__ = '0.1.0'
-__release__ = 20230201
+__version__ = '0.1.1'
+__release__ = 20230202
 __all__ = ['Log']
 
 
@@ -76,7 +76,16 @@ class Log(object, metaclass=Log2FrameType):
         return self.data._repr_html_()
 
     def __getitem__(self, mnemonics):
-        return self.data[mnemonics]
+        try:
+            return self.data[mnemonics]
+        except:
+            try:
+        		    return self.data.loc[mnemonics]
+            except:
+        		    try:
+        		        return self.data.iloc[mnemonics]
+        		    except:
+        		        raise KeyError("'" + str(mnemonics) + "' is not a curve name and is not a value in the index.")
 
     def __setitem__(self, mnemonics, curve):
         self.data[mnemonics] = curve
@@ -108,6 +117,12 @@ class Log(object, metaclass=Log2FrameType):
         else:
             logging.warning("index units are not defined.")
 
+    def set_index_units(self, units: str):
+        if hasattr(self.data, 'set_index_units'):
+            self.data.set_index_units(units)
+        if self.data.index.name in self.units:
+            self.units[self.data.index.name] = units.split()
+
     def index_to(self, index_units: str):
         if isinstance(index_units, Log):
             index_units = index_units.index_units
